@@ -8,7 +8,6 @@ new_xy_blueprint <- function(mold,
                              ptypes = NULL,
                              ...,
                              subclass = character()) {
-
   validate_is_function_set(mold)
   validate_mold_args(
     mold = mold,
@@ -26,7 +25,6 @@ new_xy_blueprint <- function(mold,
     ...,
     subclass = c(subclass, "xy_blueprint")
   )
-
 }
 
 #' @export
@@ -45,8 +43,7 @@ validate_is_xy_blueprint <- function(blueprint) {
 # ------------------------------------------------------------------------------
 
 validate_mold_args <- function(mold, required_clean_args, required_process_args) {
-
-  actual_clean_args <- rlang::fn_fmls_names(mold$clean)
+  actual_clean_args <- fn_fmls_names(mold$clean)
 
   if (!identical(actual_clean_args, required_clean_args)) {
     required_clean_args <- glue_quote_collapse(required_clean_args)
@@ -56,7 +53,7 @@ validate_mold_args <- function(mold, required_clean_args, required_process_args)
     )
   }
 
-  actual_process_args <- rlang::fn_fmls_names(mold$process)
+  actual_process_args <- fn_fmls_names(mold$process)
 
   if (!identical(required_process_args, actual_process_args)) {
     required_process_args <- glue_quote_collapse(required_process_args)
@@ -67,5 +64,4 @@ validate_mold_args <- function(mold, required_clean_args, required_process_args)
   }
 
   invisible(mold)
-
 }
