@@ -1,38 +1,32 @@
-context("test-mold-recipes")
-
-library(recipes)
-
 test_that("can mold recipes", {
-
   sparse_bp <- default_recipe_blueprint(composition = "dgCMatrix")
   matrix_bp <- default_recipe_blueprint(composition = "matrix")
 
-  rec <- recipe(Species ~ Sepal.Length, data = iris)
+  rec <- recipes::recipe(Species ~ Sepal.Length, data = iris)
   x1 <- mold(rec, iris)
   x2 <- mold(rec, iris, blueprint = sparse_bp)
   x3 <- mold(rec, iris, blueprint = matrix_bp)
 
-  expect_is(x1$predictors, "data.frame")
-  expect_is(x2$predictors, "dgCMatrix")
-  expect_is(x3$predictors, "matrix")
+  expect_s3_class(x1$predictors, "data.frame")
+  expect_s4_class(x2$predictors, "dgCMatrix")
+  expect_matrix(x3$predictors)
 
-  expect_is(x1$outcomes, "data.frame")
-  expect_is(x2$outcomes, "data.frame")
-  expect_is(x3$outcomes, "data.frame")
+  expect_s3_class(x1$outcomes, "data.frame")
+  expect_s3_class(x2$outcomes, "data.frame")
+  expect_s3_class(x3$outcomes, "data.frame")
 
   expect_equal(colnames(x1$predictors), "Sepal.Length")
   expect_equal(colnames(x2$predictors), "Sepal.Length")
   expect_equal(colnames(x3$predictors), "Sepal.Length")
-  expect_is(x1$outcomes[[1]], "factor")
-  expect_is(x1$blueprint, "default_recipe_blueprint")
+  expect_s3_class(x1$outcomes[[1]], "factor")
+  expect_s3_class(x1$blueprint, "default_recipe_blueprint")
 
   # Training data should _not_ be in the recipe
   expect_error(recipes::juice(x1$blueprint))
 })
 
 test_that("can mold recipes with intercepts", {
-
-  rec <- recipe(Species ~ Sepal.Length, data = iris)
+  rec <- recipes::recipe(Species ~ Sepal.Length, data = iris)
 
   x1 <- mold(
     rec, iris,
@@ -59,16 +53,15 @@ test_that("can mold recipes with intercepts", {
 })
 
 test_that("can pass `fresh` through to `prep()`", {
-
   sparse_bp <- default_recipe_blueprint(composition = "dgCMatrix")
 
-  iris1 <- iris[1:50,]
-  iris2 <- iris[51:100,]
+  iris1 <- iris[1:50, ]
+  iris2 <- iris[51:100, ]
 
-  rec <- recipe(Species ~ Sepal.Length, data = iris1)
-  rec <- step_center(rec, Sepal.Length)
+  rec <- recipes::recipe(Species ~ Sepal.Length, data = iris1)
+  rec <- recipes::step_center(rec, Sepal.Length)
 
-  prepped_rec <- prep(rec, iris1)
+  prepped_rec <- recipes::prep(rec, iris1)
   non_fresh_mean <- prepped_rec$steps[[1]]$means
 
   x1 <- mold(prepped_rec, iris2, blueprint = default_recipe_blueprint(fresh = FALSE))
@@ -92,16 +85,15 @@ test_that("can pass `fresh` through to `prep()`", {
 })
 
 test_that("`fresh` defaults to `TRUE`", {
-
   sparse_bp <- default_recipe_blueprint(composition = "dgCMatrix")
 
-  iris1 <- iris[1:50,]
-  iris2 <- iris[51:100,]
+  iris1 <- iris[1:50, ]
+  iris2 <- iris[51:100, ]
 
-  rec <- recipe(Species ~ Sepal.Length, data = iris1)
-  rec <- step_center(rec, Sepal.Length)
+  rec <- recipes::recipe(Species ~ Sepal.Length, data = iris1)
+  rec <- recipes::step_center(rec, Sepal.Length)
 
-  prepped_rec <- prep(rec, iris1)
+  prepped_rec <- recipes::prep(rec, iris1)
   non_fresh_mean <- prepped_rec$steps[[1]]$means
   fresh_mean <- c(Sepal.Length = mean(iris2$Sepal.Length))
 
@@ -117,20 +109,17 @@ test_that("`fresh` defaults to `TRUE`", {
 })
 
 test_that("`data` is validated", {
-
   expect_error(
-    mold(recipe(Species ~ Sepal.Length, data = iris), 1),
+    mold(recipes::recipe(Species ~ Sepal.Length, data = iris), 1),
     "`data` must be a data.frame or a matrix"
   )
-
 })
 
 test_that("`extras` holds a slot for `roles`", {
-
   sparse_bp <- default_recipe_blueprint(composition = "dgCMatrix")
   matrix_bp <- default_recipe_blueprint(composition = "matrix")
 
-  rec <- recipe(Species ~ Sepal.Length, data = iris)
+  rec <- recipes::recipe(Species ~ Sepal.Length, data = iris)
   x1 <- mold(rec, iris)
   x2 <- mold(rec, iris, blueprint = sparse_bp)
   x3 <- mold(rec, iris, blueprint = matrix_bp)
@@ -144,87 +133,84 @@ test_that("`extras` holds a slot for `roles`", {
   expect_equal(x3$blueprint$extra_role_ptypes, NULL)
 })
 
-test_that("non-standard roles columns are stored", {
+test_that("non-standard role ptypes are not retained by default", {
+  rec <- recipes::recipe(Species ~ ., iris)
+  rec <- recipes::update_role(rec, Sepal.Width, new_role = "dummy")
 
-  sparse_bp <- default_recipe_blueprint(composition = "dgCMatrix")
-  matrix_bp <- default_recipe_blueprint(composition = "matrix")
+  x <- mold(rec, iris)
 
-  rec <- recipe(Species ~ ., iris) %>%
-    update_role(Sepal.Width, new_role = "dummy")
+  expect_true("extra_role_ptypes" %in% names(x$blueprint))
 
-  x1 <- mold(rec, iris)
-  x2 <- mold(rec, iris, blueprint = sparse_bp)
-  x3 <- mold(rec, iris, blueprint = matrix_bp)
-
-  expect_equal(
-    x1$blueprint$extra_role_ptypes,
-    list(dummy = tibble::tibble(Sepal.Width = double()))
-  )
-  expect_equal(
-    x1$blueprint$extra_role_ptypes,
-    x2$blueprint$extra_role_ptypes
-  )
-  expect_equal(
-    x1$blueprint$extra_role_ptypes,
-    x3$blueprint$extra_role_ptypes
+  expect_identical(
+    x$blueprint$extra_role_ptypes,
+    NULL
   )
 
-  expect_equal(
-    x1$extras$roles,
+  # But they are returned from `mold()` for developer usage
+  expect_identical(
+    x$extras$roles,
     list(dummy = tibble::tibble(Sepal.Width = iris$Sepal.Width))
   )
-  expect_equal(
-    x1$extras$roles,
-    x2$extras$roles
-  )
-  expect_equal(
-    x1$extras$roles,
-    x3$extras$roles
+})
+
+test_that("non-standard roles ptypes can be stored upon request", {
+  bp <- default_recipe_blueprint(bake_dependent_roles = "dummy")
+
+  rec <- recipes::recipe(Species ~ ., iris)
+  rec <- recipes::update_role(rec, Sepal.Width, new_role = "dummy")
+
+  x <- mold(rec, iris, blueprint = bp)
+
+  expect_identical(
+    x$blueprint$extra_role_ptypes,
+    list(dummy = tibble::tibble(Sepal.Width = double()))
   )
 
+  expect_identical(
+    x$extras$roles,
+    list(dummy = tibble::tibble(Sepal.Width = iris$Sepal.Width))
+  )
 })
 
 test_that("only original non-standard columns are in the extra roles ptype", {
+  bp <- default_recipe_blueprint(bake_dependent_roles = "dummy")
+  sparse_bp <- default_recipe_blueprint(composition = "dgCMatrix", bake_dependent_roles = "dummy")
 
-  sparse_bp <- default_recipe_blueprint(composition = "dgCMatrix")
+  # same custom role, but note step_bs() columns aren't original columns
+  rec <- recipes::recipe(Species ~ ., iris)
+  rec <- recipes::update_role(rec, Sepal.Width, new_role = "dummy")
+  rec <- recipes::step_bs(rec, Sepal.Length, role = "dummy", deg_free = 3)
 
-  # same custom role, but not step_bs() columns arent original columns
-  rec <- recipe(Species ~ ., iris) %>%
-    update_role(Sepal.Width, new_role = "dummy") %>%
-    step_bs(Sepal.Length, role = "dummy", deg_free = 3)
-
-  x1 <- mold(rec, iris)
+  x1 <- mold(rec, iris, blueprint = bp)
   x2 <- mold(rec, iris, blueprint = sparse_bp)
 
   # extra roles ptype only has original columns
-  expect_equal(
+  expect_identical(
     colnames(x1$blueprint$extra_role_ptypes$dummy),
     "Sepal.Width"
   )
-  expect_equal(
+  expect_identical(
     colnames(x2$blueprint$extra_role_ptypes$dummy),
     "Sepal.Width"
   )
 
   # all `dummy` columns are returned in the `extras` slot
-  expect_equal(
+  expect_identical(
     colnames(x1$extras$roles$dummy),
     c("Sepal.Width", paste("Sepal.Length", c("1", "2", "3"), sep = "_bs_"))
   )
-  expect_equal(
+  expect_identical(
     colnames(x2$extras$roles$dummy),
     c("Sepal.Width", paste("Sepal.Length", c("1", "2", "3"), sep = "_bs_"))
   )
-
 })
 
 test_that("multiple extra roles types can be stored", {
-
   sparse_bp <- default_recipe_blueprint(composition = "dgCMatrix")
 
-  rec <- recipe(Species ~ ., iris) %>%
-    step_bs(Sepal.Length, role = "dummy", deg_free = 3) %>%
-    step_bs(Sepal.Width, role = "dummy2", deg_free = 3)
+  rec <- recipes::recipe(Species ~ ., iris)
+  rec <- recipes::step_bs(rec, Sepal.Length, role = "dummy", deg_free = 3)
+  rec <- recipes::step_bs(rec, Sepal.Width, role = "dummy2", deg_free = 3)
 
   x1 <- mold(rec, iris)
   x2 <- mold(rec, iris, blueprint = sparse_bp)
@@ -239,6 +225,8 @@ test_that("multiple extra roles types can be stored", {
     NULL
   )
 
+  # we don't need to request them with `bake_dependent_roles`, they
+  # automatically are returned in the `mold()` result
   expect_equal(
     names(x1$extras$roles),
     c("dummy", "dummy2")
@@ -247,19 +235,18 @@ test_that("multiple extra roles types can be stored", {
     names(x2$extras$roles),
     c("dummy", "dummy2")
   )
-
 })
 
 test_that("`NA` roles are skipped over", {
+  bp <- default_recipe_blueprint(bake_dependent_roles = "custom")
+  sparse_bp <- default_recipe_blueprint(composition = "dgCMatrix", bake_dependent_roles = "custom")
 
-  sparse_bp <- default_recipe_blueprint(composition = "dgCMatrix")
+  rec <- recipes::recipe(iris)
+  rec <- recipes::update_role(rec, Sepal.Length, new_role = "predictor")
+  rec <- recipes::update_role(rec, Species, new_role = "outcome")
+  rec <- recipes::update_role(rec, Sepal.Width, new_role = "custom")
 
-  rec <- recipe(iris) %>%
-    update_role(Sepal.Length, new_role = "predictor") %>%
-    update_role(Species, new_role = "outcome") %>%
-    update_role(Sepal.Width, new_role = "custom")
-
-  x1 <- mold(rec, iris)
+  x1 <- mold(rec, iris, blueprint = bp)
   x2 <- mold(rec, iris, blueprint = sparse_bp)
 
   expect_equal(
@@ -315,12 +302,42 @@ test_that("`NA` roles are skipped over", {
     colnames(x2$blueprint$extra_role_ptypes$custom),
     "Sepal.Width"
   )
+})
 
+test_that("non-`bake_dependent_roles` are not retained as `extra_role_ptypes`, but are in the mold result", {
+  rec <- recipes::recipe(Species ~ ., iris)
+  rec <- recipes::update_role(rec, Sepal.Width, new_role = "dummy1")
+  rec <- recipes::update_role(rec, Sepal.Length, new_role = "dummy2")
+
+  bp <- default_recipe_blueprint(bake_dependent_roles = "dummy2")
+  x <- mold(rec, iris, blueprint = bp)
+
+  expect_equal(
+    x$blueprint$extra_role_ptypes,
+    list(dummy2 = tibble::tibble(Sepal.Length = double()))
+  )
+
+  expect_equal(
+    x$extras$roles$dummy1,
+    tibble::tibble(Sepal.Width = iris$Sepal.Width)
+  )
+  expect_equal(
+    x$extras$roles$dummy2,
+    tibble::tibble(Sepal.Length = iris$Sepal.Length)
+  )
+})
+
+test_that("`bake_dependent_roles` is validated", {
+  expect_snapshot({
+    (expect_error(default_recipe_blueprint(bake_dependent_roles = 1)))
+    (expect_error(default_recipe_blueprint(bake_dependent_roles = c("outcome", "x"))))
+    (expect_error(default_recipe_blueprint(bake_dependent_roles = c("predictor", "x"))))
+  })
 })
 
 test_that("Missing y value returns a 0 column tibble for `outcomes`", {
   sparse_bp <- default_recipe_blueprint(composition = "dgCMatrix")
-  rec <- recipe(~ Sepal.Width, data = iris)
+  rec <- recipes::recipe(~Sepal.Width, data = iris)
   x1 <- mold(rec, iris)
   x2 <- mold(rec, iris, blueprint = sparse_bp)
 
@@ -331,7 +348,7 @@ test_that("Missing y value returns a 0 column tibble for `outcomes`", {
 
 test_that("Missing y value returns a 0 column / 0 row tibble for `ptype`", {
   sparse_bp <- default_recipe_blueprint(composition = "dgCMatrix")
-  rec <- recipe(~ Sepal.Width, data = iris)
+  rec <- recipes::recipe(~Sepal.Width, data = iris)
   x1 <- mold(rec, iris)
   x2 <- mold(rec, iris, blueprint = sparse_bp)
   expect_equal(x1$blueprint$ptypes$outcomes, tibble())
